@@ -276,12 +276,12 @@ void chopper_recall_loop(t_chopper *x, t_floatarg f)
   int loop_bindex = (int) f;
 
   if( loop_bindex < 0 || loop_bindex >= MAXSTORE ) {
-    error("bindex %d out of range", loop_bindex);
+    pd_error(0, "bindex %d out of range", loop_bindex);
     return;
   }
 
   if( ! x->stored_samps[ loop_bindex ] ) {
-    error("no loop stored at position %d!", loop_bindex);
+    pd_error(0, "no loop stored at position %d!", loop_bindex);
     return;
   }
 
@@ -303,7 +303,7 @@ void chopper_recall_loop(t_chopper *x, t_floatarg f)
 void chopper_set_loop(t_chopper *x, t_symbol *msg, int argc, t_atom *argv)
 {
   if( argc < 3 ) {
-    error("format: start samples increment");
+    pd_error(0, "format: start samples increment");
     return;
   }
   x->loop_start = atom_getintarg(0,argc,argv);
@@ -347,7 +347,7 @@ void chopper_init(t_chopper *x, short initialized)
     srand(time(0));
 
     if(!x->R) {
-      error("zero sampling rate - set to 44100");
+      pd_error(0, "zero sampling rate - set to 44100");
       x->R = 44100;
     }
     x->minseg = 0.1;
@@ -383,10 +383,9 @@ void chopper_init(t_chopper *x, short initialized)
     x->retro_odds = 0.5;
     x->fade_level = 1.0;
     x->lock_terminated = 0;
-
-    x->stored_starts = calloc(MAXSTORE, sizeof(int));
-    x->stored_samps = calloc(MAXSTORE, sizeof(int));
-    x->stored_increments = calloc(MAXSTORE, sizeof(int));
+    x->stored_starts = getbytes(MAXSTORE * sizeof(int));
+    x->stored_samps = getbytes(MAXSTORE * sizeof(int));
+    x->stored_increments = getbytes(MAXSTORE * sizeof(int));
 
   } else {
     x->taper_samps = x->R * x->taper_duration;
@@ -397,9 +396,9 @@ void chopper_init(t_chopper *x, short initialized)
 
 void chopper_free(t_chopper *x)
 {
-  free(x->stored_increments);
-  free(x->stored_samps);
-  free(x->stored_starts);
+  freebytes(x->stored_increments, MAXSTORE * sizeof(int));
+  freebytes(x->stored_samps, MAXSTORE * sizeof(int));
+  freebytes(x->stored_starts, MAXSTORE * sizeof(int));
 }
 
 void chopper_jitterme(t_chopper *x)
@@ -409,12 +408,12 @@ void chopper_jitterme(t_chopper *x)
   new_start = (1.0 + chopper_boundrand(-jitter_factor, jitter_factor) ) * (float) x->loop_start ;
 
   if( new_start < 0 ) {
-//    error("jitter loop %d out of range", new_start);
+//    pd_error(0, "jitter loop %d out of range", new_start);
     new_start = 0;
 
   }
   else if( new_start + x->transp_loop_samps >= x->framesize ) {
-//    error("jitter loop %d out of range", new_start);
+//    pd_error(0, "jitter loop %d out of range", new_start);
     new_start = x->framesize - x->transp_loop_samps ;
   }
   if( new_start >= 0 )
@@ -522,7 +521,7 @@ void chopper_randloop( t_chopper *x )
       loop_start = framesize - loop_samps;
       if( loop_start < 0 ) {
         loop_start = 0;
-        error("negative starttime");
+        pd_error(0, "negative starttime");
       }
     }
   }
@@ -543,7 +542,7 @@ void chopper_randloop( t_chopper *x )
 
 t_int *chopper_pd_perform(t_int *w)
 {
-  int bindex, bindex2;
+  int bindex;
   float sample1, m1, m2;
   t_chopper *x = (t_chopper *)(w[1]);
   t_float *out1 = (t_float *)(w[2]);
@@ -659,7 +658,7 @@ t_int *chopper_pd_perform(t_int *w)
 
           force_new_loop = 0;
           bindex = x->fbindex ;
-          bindex2 = bindex << 1;
+ //         bindex2 = bindex << 1;
           x->fbindex += x->increment;
 
           --(x->samps_to_go);
@@ -685,7 +684,7 @@ t_int *chopper_pd_perform(t_int *w)
       else {
 
         if( bindex < 0 || bindex >= b_frames ) {
-          // error("lock_loop: bindex %d is out of range", bindex);
+          // pd_error(0, "lock_loop: bindex %d is out of range", bindex);
           x->fbindex = bindex = b_frames / 2;
         }
         bindex = floor( (double) x->fbindex );
@@ -757,7 +756,7 @@ t_int *chopper_pd_perform(t_int *w)
         fade_level = 1.0; /* default level */
 
         if( bindex < 0 || bindex >= b_frames ) {
-          // error("force loop: bindex %d is out of range", bindex);
+          // pd_error(0, "force loop: bindex %d is out of range", bindex);
           /* post("frames:%d start:%d, samps2go:%d, tloopsamps:%d, increment:%f",
                x->framesize, bindex, x->samps_to_go, x->transp_loop_samps, x->increment);*/
           chopper_randloop(x);
@@ -819,7 +818,7 @@ void chopper_set_minincr(t_chopper *x, t_floatarg n)
   if( n < .005 ) {
     n = .005;
   }
-  //x->minincr = n ;
+  x->minincr = n ;
 }
 
 // set deviation factor
