@@ -1,13 +1,12 @@
 #include "m_pd.h"
-//#include "lpp.h"
 #include "fftease.h"
 #include "MSPd.h"
 
 #define OBJECT_NAME "convolver~"
 #define DENORM_WANT_FIX   1
 
-#define COMPILE_DATE "1.7.08"
-#define OBJECT_VERSION "2.02"
+#define COMPILE_DATE "9.4.22"
+#define OBJECT_VERSION "2.03"
 
 #define FIX_DENORM_FLOAT(v) (v=(fabs(v) < 0.000001 ? 0.f : (v)))
 static t_class *convolver_class;
@@ -48,25 +47,17 @@ typedef struct _convolver
     short static_memory; // flag to avoid dynamic memory manipulation
 } t_convolver;
 
-// maybe no dsp method
+
 static float boundrand(float min, float max);
 static void convolver_setbuf(t_buffy *trybuf);
-
 static void *convolver_new(t_symbol *msg, int argc, t_atom *argv);
 static t_int *convolver_perform(t_int *w);
-
-static void convolver_mute(t_convolver *x, t_floatarg toggle);
-static void convolver_assist (t_convolver *x, void *b, long msg, long arg, char *dst);
 static void convolver_dsp_free(t_convolver *x);
-static void convolver_seed(t_convolver *x, t_floatarg seed);
-// void convolver_dsp(t_convolver *x, t_signal **sp, short *count);
 static void convolver_attach_buffers(t_convolver *x) ;
 static void convolver_spikeimp(t_convolver *x, t_floatarg density);
 static void convolver_convolve(t_convolver *x);
 static void convolver_convolvechans(t_convolver *x, t_symbol *msg, int argc, t_atom *argv);
-static void convolver_version(t_convolver *x);
 static void convolver_noiseimp(t_convolver *x, t_floatarg curve);
-
 static void rfft( float *x, int N, int forward );
 static void cfft( float *x, int NC, int forward );
 static void rdft(int n, int isgn, float *a, int *ip, float *w);
@@ -74,7 +65,6 @@ static void bitreverse( float *x, int N );
 static void init_rdft(int n, int *ip, float *w);
 static void convolver_static_memory(t_convolver *x, t_floatarg toggle);
 
-
 void convolver_tilde_setup(void) {
     convolver_class = class_new(gensym("convolver~"), (t_newmethod)convolver_new,
                                 (t_method)convolver_dsp_free,sizeof(t_convolver), 0,A_GIMME,0);
@@ -113,32 +103,35 @@ void convolver_static_memory(t_convolver *x, t_floatarg toggle)
         
         post("%s: memory is now static - do not reload your impulse buffer",OBJECT_NAME);
         
-        if ((sbuf = (float *) calloc(N+2, sizeof(float))) == NULL)
-            error("%s: insufficient memory", OBJECT_NAME);
+        if ((sbuf = (float *) getbytes((N+2) * sizeof(float))) == NULL)
+            pd_error(0, "%s: insufficient memory", OBJECT_NAME);
         memcount += (N+2) * sizeof(float);
-        if ((tbuf = (float *) calloc(N2, sizeof(float))) == NULL)
-            error("%s: insufficient memory",OBJECT_NAME);
+        if ((tbuf = (float *) getbytes(N2 * sizeof(float))) == NULL)
+            pd_error(0, "%s: insufficient memory",OBJECT_NAME);
         memcount += (N2) * sizeof(float);
-        if ((filt = (float *) calloc(N+2, sizeof(float))) == NULL)
-            error("%s: insufficient memory",OBJECT_NAME);
+        if ((filt = (float *) getbytes((N+2) * sizeof(float))) == NULL)
+            pd_error(0, "%s: insufficient memory",OBJECT_NAME);
         memcount += (N+2) * sizeof(float);
-        if( (bitshuffle = (int *) calloc(N * 2, sizeof(int))) == NULL)
-            error("%s: insufficient memory",OBJECT_NAME);
+        if( (bitshuffle = (int *) getbytes((N*2) * sizeof(int))) == NULL)
+            pd_error(0, "%s: insufficient memory",OBJECT_NAME);
         memcount += (N2) * sizeof(float);
-        if( (trigland = (float *) calloc(N * 2, sizeof(float))) == NULL)
-            error("%s: insufficient memory",OBJECT_NAME);
+        if( (trigland = (float *) getbytes((N*2) * sizeof(float))) == NULL)
+            pd_error(0, "%s: insufficient memory",OBJECT_NAME);
         memcount += (N2) * sizeof(float);
         post("%s: allocated %f Megabytes for %s", OBJECT_NAME, (float)memcount / 1000000.0, impulse->myname->s_name);
+        x->N = N;
+        x->N2 = N2;
     }
 }
 
 
-
+/*
 void convolver_seed(t_convolver *x, t_floatarg seed)
 {
     (void)x;
     srand((long)seed);
 }
+*/
 
 void convolver_convolve(t_convolver *x)
 {
@@ -146,7 +139,7 @@ void convolver_convolve(t_convolver *x)
     t_symbol *mymsg;
     short myargc = 3;
     t_atom data[3];
-    mymsg = (t_symbol *) calloc(1, sizeof(t_symbol));
+    mymsg = (t_symbol *) getbytes(1 * sizeof(t_symbol));
     convolver_attach_buffers( x );
     if(x->source->b_nchans == x->impulse->b_nchans && x->impulse->b_nchans == x->dest->b_nchans) {
         //post("case 1");
@@ -211,19 +204,19 @@ void convolver_convolvechans(t_convolver *x, t_symbol *msg, int argc, t_atom *ar
     dest_chan = atom_getfloatarg(2,argc,argv);
     // post("chans %d %d %d", source_chan, impulse_chan, dest_chan);
     if( source_chan <= 0 || impulse_chan <= 0 || dest_chan <= 0) {
-        error("%s: channels are counted starting from 1",OBJECT_NAME);
+        pd_error(0, "%s: channels are counted starting from 1",OBJECT_NAME);
         return;
     }
     if( source_chan > source->b_nchans ) {
-        error("%s: source channel %ld out of range", OBJECT_NAME, source_chan);
+        pd_error(0, "%s: source channel %ld out of range", OBJECT_NAME, source_chan);
         return;
     }
     if( impulse_chan > impulse->b_nchans ) {
-        error("%s: impulse channel %ld out of range", OBJECT_NAME, impulse_chan);
+        pd_error(0, "%s: impulse channel %ld out of range", OBJECT_NAME, impulse_chan);
         return;
     }
     if( dest_chan > dest->b_nchans ) {
-        error("%s: dest channel %ld out of range", OBJECT_NAME, dest_chan);
+        pd_error(0, "%s: dest channel %ld out of range", OBJECT_NAME, dest_chan);
         return;
     }
     --source_chan;
@@ -242,23 +235,21 @@ void convolver_convolvechans(t_convolver *x, t_symbol *msg, int argc, t_atom *ar
     
     // post("size of N for convolution is %d", N);
     if(! x->static_memory ) {
-        if ((sbuf = (float *) calloc(N+2, sizeof(float))) == NULL)
-            error("%s: insufficient memory", OBJECT_NAME);
-        if ((tbuf = (float *) calloc(N2, sizeof(float))) == NULL)
-            error("%s: insufficient memory",OBJECT_NAME);
-        if ((filt = (float *) calloc(N+2, sizeof(float))) == NULL)
-            error("%s: insufficient memory",OBJECT_NAME);
-        if( (bitshuffle = (int *) calloc(N * 2, sizeof(int))) == NULL)
-            error("%s: insufficient memory",OBJECT_NAME);
-        if( (trigland = (float *) calloc(N * 2, sizeof(float))) == NULL)
-            error("%s: insufficient memory",OBJECT_NAME);
+        if ((sbuf = (float *) getbytes((N+2) * sizeof(float))) == NULL)
+            pd_error(0, "%s: insufficient memory", OBJECT_NAME);
+        if ((tbuf = (float *) getbytes(N2 * sizeof(float))) == NULL)
+            pd_error(0, "%s: insufficient memory",OBJECT_NAME);
+        if ((filt = (float *) getbytes((N+2) * sizeof(float))) == NULL)
+            pd_error(0, "%s: insufficient memory",OBJECT_NAME);
+        if( (bitshuffle = (int *) getbytes((N*2) * sizeof(int))) == NULL)
+            pd_error(0, "%s: insufficient memory",OBJECT_NAME);
+        if( (trigland = (float *) getbytes((N*2) * sizeof(float))) == NULL)
+            pd_error(0, "%s: insufficient memory",OBJECT_NAME);
     }
     
     x->mult = 1. / (float) N;
     x->last_N = N;
-    init_rdft( N, bitshuffle, trigland);
-    
-    
+    init_rdft(N, bitshuffle, trigland);
     
     for(i = 0, j = 0; i < impulse->b_frames; i+= impulse->b_nchans, j++) {
         filt[j] = impulse->b_samples[i + impulse_chan].w_float;
@@ -279,7 +270,7 @@ void convolver_convolvechans(t_convolver *x, t_symbol *msg, int argc, t_atom *ar
         max = gain/(sqrt(max));
     }
     else {
-        error("%s: impulse response is all zeros",OBJECT_NAME);
+        pd_error(0, "%s: impulse response is all zeros",OBJECT_NAME);
         return;
     }
     // make normalization optional
@@ -393,15 +384,18 @@ void convolver_convolvechans(t_convolver *x, t_symbol *msg, int argc, t_atom *ar
     //  return;
     
     if(! x->static_memory ) {
-        free(sbuf);
-        free(tbuf);
-        free(filt);
-        free(bitshuffle);
-        free(trigland);
-        
+        freebytes(sbuf,(N+2) * sizeof(float));
+        freebytes(tbuf,N2 * sizeof(float));
+        freebytes(filt,(N+2) * sizeof(float));
+        freebytes(bitshuffle,(N*2) * sizeof(int));
+        freebytes(trigland,(N*2) * sizeof(float));
+    } else {
+        x->N = N;
+        x->N2 =  N2;
     }
     outlet_bang(x->bang);
     garray_redraw(x->dest->b);
+
 }
 
 void convolver_noiseimp(t_convolver *x, t_floatarg curve)
@@ -426,7 +420,7 @@ void convolver_noiseimp(t_convolver *x, t_floatarg curve)
     b_samples = x->impulse->b_samples;
     // chan test
     if( sr == 0. ) {
-        error("zero sample rate");
+        pd_error(0, "zero sample rate");
         return;
     }
     // zero out buffer
@@ -480,7 +474,7 @@ void convolver_spikeimp(t_convolver *x, t_floatarg density)
     b_samples = x->impulse->b_samples;
     // chan test
     if( sr == 0. ) {
-        error("zero sample rate");
+        pd_error(0, "zero sample rate");
         return;
     }
     // zero out buffer
@@ -503,7 +497,7 @@ void convolver_spikeimp(t_convolver *x, t_floatarg density)
             }
             position = (int) (dur * guess * guess * sr) * b_nchans + j;
             if( position >= b_frames * b_nchans ) {
-                error("%d exceeds %ld",position, b_frames * b_nchans);
+                pd_error(0, "%d exceeds %ld",position, b_frames * b_nchans);
             } else{
                 b_samples[ position ].w_float = gain;
             }
@@ -526,9 +520,9 @@ void *convolver_new(t_symbol *msg, int argc, t_atom *argv)
     (void)msg;
     x->bang = outlet_new(&x->x_obj, gensym("bang"));
     srand(time(0)); //need "seed" message
-    x->impulse = (t_buffy *)malloc(sizeof(t_buffy));
-    x->source = (t_buffy *)malloc(sizeof(t_buffy));
-    x->dest = (t_buffy *)malloc(sizeof(t_buffy));
+    x->impulse = (t_buffy *)getbytes(sizeof(t_buffy));
+    x->source = (t_buffy *)getbytes(sizeof(t_buffy));
+    x->dest = (t_buffy *)getbytes(sizeof(t_buffy));
     x->static_memory = 0;
     
     // default names
@@ -543,7 +537,7 @@ void *convolver_new(t_symbol *msg, int argc, t_atom *argv)
     x->dest->myname = atom_getsymbolarg(2,argc,argv);
     
     x->sr = sys_getsr();
-    return (x);
+    return x;
 }
 
 
@@ -561,10 +555,10 @@ void convolver_setbuf(t_buffy *trybuf)
     int b_frames;
     /* load up sample array */
     if (!(a = (t_garray *)pd_findbyclass(trybuf->myname, garray_class))) {
-        if (*trybuf->myname->s_name) error("%s: %s: no such array", OBJECT_NAME, trybuf->myname->s_name);
+        if (*trybuf->myname->s_name) pd_error(0, "%s: %s: no such array", OBJECT_NAME, trybuf->myname->s_name);
     }
     else if (!garray_getfloatwords(a, &b_frames, &trybuf->b_samples)) { // possible crash worry?
-        error("%s: bad template for %s", trybuf->myname->s_name,OBJECT_NAME);
+        pd_error(0, "%s: bad template for %s", trybuf->myname->s_name,OBJECT_NAME);
         trybuf->b_valid = 0;
     }
     else  {
@@ -575,21 +569,27 @@ void convolver_setbuf(t_buffy *trybuf)
     }
 }
 
-
+/*
 t_int *convolver_perform(t_int *w)
 {
     return w + 4; // maybe we don't need this guy at all
 }
+*/
 
 void convolver_dsp_free(t_convolver *x)
 {
+    int N = x->N;
+    int N2 = x->N2;
+    freebytes(x->impulse, sizeof(t_buffy));
+    freebytes(x->source, sizeof(t_buffy));
+    freebytes(x->dest, sizeof(t_buffy));
     if( x->static_memory ) {
-        free(x->sbuf);
-        free(x->tbuf);
-        free(x->filt);
-        free(x->bitshuffle);
-        free(x->trigland);
-        outlet_bang(x->bang);
+        freebytes(x->sbuf, (N+2) * sizeof(float));
+        freebytes(x->tbuf, N2 * sizeof(float));
+        freebytes(x->filt, (N+2) * sizeof(float));
+        freebytes(x->bitshuffle, (N*2) * sizeof(int));
+        freebytes(x->trigland, (N*2) * sizeof(float));
+       //  outlet_bang(x->bang);
     }
 }
 
