@@ -150,7 +150,7 @@ void dmach_muteslot(t_dmach *x, t_symbol *s, int argc, t_atom *argv)
 
 
   if(slot < 0 || slot > drum_count - 1) {
-    error("muteslot: illegal slot index: %d",slot);
+    pd_error(0, "muteslot: illegal slot index: %d",slot);
     return;
   }
   x->muted[slot] = mutestate;
@@ -168,14 +168,14 @@ void dmach_playsequence(t_dmach *x, t_symbol *s, int argc, t_atom *argv)
   int pnum;
 
   if(argc < 1) {
-    error("%s: zero length sequence",OBJECT_NAME);
+    pd_error(0, "%s: zero length sequence",OBJECT_NAME);
     return;
   }
   /* need safety check here */
   for(i = 0; i < argc; i++) {
     pnum = (int) atom_getfloatarg(i,argc,argv);
     if(! x->stored_patterns[pnum]) {
-      error("%d is not currently stored",pnum);
+      pd_error(0, "%d is not currently stored",pnum);
       return;
     }
   }
@@ -206,14 +206,14 @@ void dmach_loopsequence(t_dmach *x, t_symbol *s, int argc, t_atom *argv)
   int pnum;
 
   if(argc < 1) {
-    error("%s: zero length sequence",OBJECT_NAME);
+    pd_error(0, "%s: zero length sequence",OBJECT_NAME);
     return;
   }
 
   for(i = 0; i < argc; i++) {
     pnum = (int) atom_getfloatarg(i,argc,argv);
     if(! x->stored_patterns[pnum]) {
-      error("%d is not currently stored",pnum);
+      pd_error(0, "%d is not currently stored",pnum);
       return;
     }
   }
@@ -248,11 +248,11 @@ void dmach_gain(t_dmach *x, t_floatarg slotf, t_floatarg new_gain_factor)
   //  int i,j,k;
 
   if(slot < 0 || slot > drum_count - 1) {
-    error("illegal slot index: %d",slot);
+    pd_error(0, "illegal slot index: %d",slot);
     return;
   }
   /* if(new_gain_factor <= 0) {
-     error("illegal gain factor %f", new_gain_factor);
+     pd_error(0, "illegal gain factor %f", new_gain_factor);
      return;
      } */
   //  gain_factor = gains[slot];
@@ -267,11 +267,11 @@ void dmach_transpose(t_dmach *x, t_floatarg slotf, t_floatarg new_transpose_fact
   int drum_count = x->drum_count;
 
   if(slot < 0 || slot > drum_count - 1) {
-    error("%s: transpose given illegal slot index: %d",OBJECT_NAME, slot);
+    pd_error(0, "%s: transpose given illegal slot index: %d",OBJECT_NAME, slot);
     return;
   }
   if(new_transpose_factor == 0) {
-    error("illegal transpose factor %f", new_transpose_factor);
+    pd_error(0, "illegal transpose factor %f", new_transpose_factor);
     return;
   }
   gtranspose[slot] = new_transpose_factor;
@@ -286,15 +286,15 @@ void dmach_recall(t_dmach *x, t_floatarg pnf)
   /* post("requested recall of %d, ignored",pnum);
      return;*/
   if(pnum < 0) {
-    error("requested index is less than zero");
+    pd_error(0, "requested index is less than zero");
     return;
   }
   if(pnum >= MAX_PATTERNS) {
-    error("requested index is greater than the maximum of %d",MAX_PATTERNS-1);
+    pd_error(0, "requested index is greater than the maximum of %d",MAX_PATTERNS-1);
     return;
   }
   if(! x->stored_patterns[pnum]) {
-    error("%d is not currently stored",pnum);
+    pd_error(0, "%d is not currently stored",pnum);
     return;
   }
   //  x->this_pattern = x->next_pattern = pnum;
@@ -309,15 +309,15 @@ void dmach_arm(t_dmach *x, t_floatarg pnf)
   t_pattern *p = x->patterns;
 
   if(pnum < 0) {
-    error("requested index is less than zero");
+    pd_error(0, "requested index is less than zero");
     return;
   }
   if(pnum > MAX_PATTERNS) {
-    error("%s: requested index is greater than the maximum of %d",OBJECT_NAME,MAX_PATTERNS-1);
+    pd_error(0, "%s: requested index is greater than the maximum of %d",OBJECT_NAME,MAX_PATTERNS-1);
     return;
   }
   if(! x->stored_patterns[pnum]) {
-    error("%s: %d is not currently stored",OBJECT_NAME,pnum);
+    pd_error(0, "%s: %d is not currently stored",OBJECT_NAME,pnum);
     return;
   }
   x->mute = 1;
@@ -339,7 +339,7 @@ void dmach_tempo(t_dmach *x, t_floatarg new_tempo)
   float sr = x->sr;
   float tempo_factor = x->tempo_factor;
   if(new_tempo <= 0.0) {
-    error("tempo must be greater than zero, but was %f",new_tempo);
+    pd_error(0, "tempo must be greater than zero, but was %f",new_tempo);
     return;
   }
   ratio = x->tempo / new_tempo;
@@ -370,12 +370,12 @@ void dmach_show(t_dmach *x, t_floatarg fn)
   int drum_count = x->drum_count;
 
   if(pnum < 0 || pnum > MAX_PATTERNS-1) {
-    error("illegal pattern number: %d",pnum);
+    pd_error(0, "illegal pattern number: %d",pnum);
     return;
   }
 
   if(! x->stored_patterns[pnum]) {
-    error("%d is not currently stored",pnum);
+    pd_error(0, "%d is not currently stored",pnum);
     return;
   }
   post("showing pattern %d",pnum);
@@ -407,16 +407,16 @@ void dmach_printraw(t_dmach *x, t_floatarg fn)
   float sr = x->sr;
 
   if(pnum < 0 || pnum > MAX_PATTERNS-1) {
-    error("illegal pattern number: %d",pnum);
+    pd_error(0, "illegal pattern number: %d",pnum);
     return;
   }
 
   if(! x->stored_patterns[pnum]) {
-    error("%d is not currently stored",pnum);
+    pd_error(0, "%d is not currently stored",pnum);
     return;
   }
   if(!tempo_factor) {
-    error("tempo factor is zero!");
+    pd_error(0, "tempo factor is zero!");
     return;
   }
 
@@ -456,16 +456,16 @@ void dmach_listraw(t_dmach *x, t_symbol *s, int argc, t_atom *argv)
     pnum = (int) atom_getfloatarg(0,argc,argv);
   }
   if(pnum < 0 || pnum > MAX_PATTERNS-1) {
-    error("illegal pattern number: %d",pnum);
+    pd_error(0, "illegal pattern number: %d",pnum);
     return;
   }
 
   if(! x->stored_patterns[pnum]) {
-    error("%d is not currently stored",pnum);
+    pd_error(0, "%d is not currently stored",pnum);
     return;
   }
   if(!tempo_factor) {
-    error("tempo factor is zero!");
+    pd_error(0, "tempo factor is zero!");
     return;
   }
 
@@ -506,19 +506,19 @@ void dmach_copypattern(t_dmach *x, t_floatarg pn1, t_floatarg pn2)
   int drum_count = x->drum_count;
 
   if(pnum_from < 0 || pnum_from > MAX_PATTERNS-1) {
-    error("illegal source pattern number: %d",pnum_from);
+    pd_error(0, "illegal source pattern number: %d",pnum_from);
     return;
   }
   if(pnum_to < 0 || pnum_to > MAX_PATTERNS-1) {
-    error("illegal dest pattern number: %d",pnum_to);
+    pd_error(0, "illegal dest pattern number: %d",pnum_to);
     return;
   }
   if(pnum_from == pnum_to) {
-    error("source and dest patterns are the same");
+    pd_error(0, "source and dest patterns are the same");
     return;
   }
   if(! x->stored_patterns[pnum_from]) {
-    error("%d is not currently stored",pnum_from);
+    pd_error(0, "%d is not currently stored",pnum_from);
     return;
   }
   dmach_init_pattern(x,pnum_to);
@@ -564,7 +564,7 @@ void dmach_readraw(t_dmach *x, t_symbol *s, int argc, t_atom *argv)
 
 
   if(pnum < 0 || pnum > MAX_PATTERNS-1) {
-    error("%s: illegal pattern number: %d",OBJECT_NAME,pnum);
+    pd_error(0, "%s: illegal pattern number: %d",OBJECT_NAME,pnum);
     return;
   }
 
@@ -627,12 +627,12 @@ void dmach_slotamps(t_dmach *x, t_symbol *s, int argc, t_atom *argv)
     return;*/
 
   if(pnum < 0 || pnum > MAX_PATTERNS - 1) {
-    error("%s: invalid pattern number: %d",OBJECT_NAME,pnum);
+    pd_error(0, "%s: invalid pattern number: %d",OBJECT_NAME,pnum);
     return;
   }
 
   if(!x->stored_patterns[pnum]) {
-    error("%s: no pattern found at location : %d",OBJECT_NAME,pnum);
+    pd_error(0, "%s: no pattern found at location : %d",OBJECT_NAME,pnum);
     return;
   }
 
@@ -644,7 +644,7 @@ void dmach_slotamps(t_dmach *x, t_symbol *s, int argc, t_atom *argv)
   //  post("filling slotamps %d for %d",slot, pnum);
   if(tempo <= 0) {
     tempo = 60;
-    error("zero tempo found");
+    pd_error(0, "zero tempo found");
   }
   tempo_factor = (60.0/tempo);
 
@@ -717,12 +717,12 @@ void dmach_slotampsfull(t_dmach *x, t_symbol *s, int argc, t_atom *argv)
   pnum = atom_getfloatarg(pdex++,argc,argv);
 
   if(pnum < 0 || pnum > MAX_PATTERNS - 1) {
-    error("%s: invalid pattern number: %d",OBJECT_NAME,pnum);
+    pd_error(0, "%s: invalid pattern number: %d",OBJECT_NAME,pnum);
     return;
   }
 
   if(!x->stored_patterns[pnum]) {
-    error("%s: no pattern found at location : %d",OBJECT_NAME,pnum);
+    pd_error(0, "%s: no pattern found at location : %d",OBJECT_NAME,pnum);
     return;
   }
 
@@ -791,12 +791,12 @@ void dmach_slotincrs(t_dmach *x, t_symbol *s, int argc, t_atom *argv)
 
 
   if(pnum < 0 || pnum >= MAX_PATTERNS) {
-    error("%s: slotincrs sent invalid pattern number: %d",OBJECT_NAME,pnum);
+    pd_error(0, "%s: slotincrs sent invalid pattern number: %d",OBJECT_NAME,pnum);
     return;
   }
 
   if(!x->stored_patterns[pnum]) {
-    error("%s: slotincrs: no pattern found at location : %d",OBJECT_NAME,pnum);
+    pd_error(0, "%s: slotincrs: no pattern found at location : %d",OBJECT_NAME,pnum);
     return;
   }
 
@@ -838,7 +838,7 @@ void dmach_store(t_dmach *x, t_symbol *s, int argc, t_atom *argv)
 
   pnum = atom_getfloatarg(0,argc,argv);
   if(pnum < 0 || pnum > MAX_PATTERNS - 1) {
-    error("invalid pattern number: %d",pnum);
+    pd_error(0, "invalid pattern number: %d",pnum);
     return;
   }
   //  post("%d arguments to \"store\" at pattern %d",argc,pnum);
@@ -851,7 +851,7 @@ void dmach_store(t_dmach *x, t_symbol *s, int argc, t_atom *argv)
     p[pnum].beats = 4;
   }
   if(tempo <= 0) {
-    error("zero tempo in store msg");
+    pd_error(0, "zero tempo in store msg");
     tempo = 60;
   }
   tempo_factor = (60.0/tempo);
@@ -911,7 +911,7 @@ void dmach_init_pattern(t_dmach *x, int pnum)
   int drum_count = x->drum_count;
   t_pattern *p = x->patterns;
   if(pnum < 0 || pnum >= MAX_PATTERNS) {
-    error("invalid pattern number: %d",pnum);
+    pd_error(0, "invalid pattern number: %d",pnum);
     return;
   }
 
@@ -922,13 +922,12 @@ void dmach_init_pattern(t_dmach *x, int pnum)
   }
 
   if(p[pnum].drumlines == NULL) {
-    // post("initializing drumline memory at location %d",pnum);
-    p[pnum].drumlines = (t_drumline *)malloc(drum_count * sizeof(t_drumline));
+    p[pnum].drumlines = (t_drumline *)getbytes(drum_count * sizeof(t_drumline));
   }
 
-
+// possible memory leak
   for(i = 0; i < drum_count; i++) {
-    p[pnum].drumlines[i].attacks = (t_attack *)calloc(MAX_ATTACKS, sizeof(t_attack));
+    p[pnum].drumlines[i].attacks = (t_attack *)getbytes(MAX_ATTACKS * sizeof(t_attack));
     p[pnum].drumlines[i].adex = 0;
     p[pnum].drumlines[i].active = 0;
     p[pnum].drumlines[i].attack_count = 0;
@@ -939,17 +938,20 @@ void dmach_init_pattern(t_dmach *x, int pnum)
 
 void dmach_dsp_free( t_dmach *x )
 {
+    /*
+     p[pnum].drumlines = (t_drumline *)getbytes(drum_count * sizeof(t_drumline));
+     */
   /* need some freeing action here! */
-  free(x->patterns);
-  free(x->stored_patterns);
-  free(x->current_increment);
-  free(x->gtranspose);
-  free(x->gains);
-  free(x->sequence);
-  free(x->listdata);
-  free(x->connected);
-  free(x->tmpatks);
-  free(x->muted);
+  freebytes(x->patterns,MAX_PATTERNS * sizeof(t_pattern));
+  freebytes(x->stored_patterns,MAX_PATTERNS * sizeof(short));
+  freebytes(x->current_increment,x->drum_count * sizeof(float));
+  freebytes(x->gtranspose,x->drum_count * sizeof(float));
+  freebytes(x->gains,x->drum_count * sizeof(float));
+  freebytes(x->sequence,1024 * sizeof(int));
+  freebytes(x->listdata,1024 * sizeof(t_atom));
+  freebytes(x->connected,1024 * sizeof(short));
+  freebytes(x->tmpatks,MAX_ATTACKS * sizeof(t_attack));
+  freebytes(x->muted,x->drum_count * sizeof(short));
 }
 
 void dmach_mute(t_dmach *x, t_floatarg toggle)
@@ -990,16 +992,16 @@ void *dmach_new(t_symbol *s, int argc, t_atom *argv)
     outlet_new(&x->x_obj, gensym("signal"));
   }
   x->listraw_outlet = outlet_new(&x->x_obj, gensym("list"));
-  x->patterns = (t_pattern *) malloc(MAX_PATTERNS * sizeof(t_pattern));
-  x->stored_patterns = (short *) malloc(MAX_PATTERNS * sizeof(short));
-  x->current_increment = (float *) malloc(x->drum_count * sizeof(float)); // for sample + hold of increment
-  x->gtranspose = (float *) malloc(x->drum_count * sizeof(float));
-  x->gains = (float *) malloc(x->drum_count * sizeof(float));
-  x->sequence = (int *) malloc(1024 * sizeof(int));
-  x->listdata = (t_atom *) malloc(1024 * sizeof(t_atom));
-  x->connected = (short *) malloc(1024 * sizeof(short));
-  x->tmpatks = (t_attack *)calloc(MAX_ATTACKS, sizeof(t_attack));
-  x->muted = (short *)calloc(x->drum_count, sizeof(short)); // by default mute is off on each slot
+  x->patterns = (t_pattern *) getbytes(MAX_PATTERNS * sizeof(t_pattern));
+  x->stored_patterns = (short *) getbytes(MAX_PATTERNS * sizeof(short));
+  x->current_increment = (float *) getbytes(x->drum_count * sizeof(float)); // for sample + hold of increment
+  x->gtranspose = (float *) getbytes(x->drum_count * sizeof(float));
+  x->gains = (float *) getbytes(x->drum_count * sizeof(float));
+  x->sequence = (int *) getbytes(1024 * sizeof(int));
+  x->listdata = (t_atom *) getbytes(1024 * sizeof(t_atom));
+  x->connected = (short *) getbytes(1024 * sizeof(short));
+  x->tmpatks = (t_attack *)getbytes(MAX_ATTACKS * sizeof(t_attack));
+  x->muted = (short *)getbytes(x->drum_count * sizeof(short)); // by default mute is off on each slot
 
   x->seqptr = 0;
   x->sequence_length = 0;
@@ -1207,9 +1209,9 @@ void dmach_dsp(t_dmach *x, t_signal **sp)
   }
 
 
-  sigvec  = (t_int **) calloc(pointer_count, sizeof(t_int *));
+  sigvec  = (t_int **) getbytes(pointer_count * sizeof(t_int *));
   for(i = 0; i < pointer_count; i++) {
-    sigvec[i] = (t_int *) calloc(sizeof(t_int),1);
+    sigvec[i] = (t_int *) getbytes(sizeof(t_int) * 1);
   }
   sigvec[0] = (t_int *)x; // first pointer is to the object
 
@@ -1220,5 +1222,5 @@ void dmach_dsp(t_dmach *x, t_signal **sp)
   }
 
   dsp_addv(dmach_perform, pointer_count, (t_int *) sigvec);
-  free(sigvec);
+  freebytes(sigvec,pointer_count * sizeof(t_int *));
 }
